Enum pallet_election_provider_multi_phase::Phase [−][src]
Current phase of the pallet.
Variants
Nothing, the election is not happening.
Signed phase is open.
Unsigned phase. First element is whether it is active or not, second the starting block number.
We do not yet check whether the unsigned phase is active or passive. The intent is for the blockchain to be able to declare: “I believe that there exists an adequate signed solution,” advising validators not to bother running the unsigned offchain worker.
As validator nodes are free to edit their OCW code, they could simply ignore this advisory and always compute their own solution. However, by default, when the unsigned phase is passive, the offchain workers will not bother running.
The emergency phase. This is enabled upon a failing call to T::ElectionProvider::elect.
After that, the only way to leave this phase is through a successful
T::ElectionProvider::elect.
Implementations
Whether the phase is emergency or not.
Whether the phase is unsigned or not.
Whether the phase is unsigned and open or not, with specific start.
Whether the phase is unsigned and open or not.