Struct pallet_election_provider_multi_phase::signed::SignedSubmissions [−][src]
pub struct SignedSubmissions<T: Config> { /* fields omitted */ }Expand description
Mask type which pretends to be a set of SignedSubmissionOf<T>, while in fact delegating to the
actual implementations in SignedSubmissionIndices<T>, SignedSubmissionsMap<T>, and
SignedSubmissionNextIndex<T>.
Implementations
Iterate through the set of signed submissions in order of increasing score.
Decode the length of the signed submissions without actually reading the entire struct into memory.
Note that if you hold an instance of SignedSubmissions, this function does not
track its current length. This only decodes what is currently stored in memory.
Insert a new signed submission into the set.
In the event that the new submission is not better than the current weakest according
to is_score_better, we do not change anything.
Remove the signed submission with the highest score from the set.